==> nextcloud-18.0.4.tgz: nextcloud/apps/oauth2/l10n/gl.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "O seu cliente non ten autorización para conectarse. Informe do seu cliente ao administrador.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "o seu URL de redirección debe ser un URL completo, por exemplo: https://omeudominio.com/ruta",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Permite a autenticación compatíbel con OAuth2 dende outras aplicacións web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "A aplicación OAuth2 permítelle aos administradores configurar o fluxo de traballo de autenticación incorporado para permitir tamén autenticación compatíbel con OAuth2 dende outras aplicacións web.",
    "OAuth 2.0 clients" : "Clientes OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 permítelle aos servizos externos solicitar acceso a {instanceName}.",
    "Name" : "Nome",
    "Redirection URI" : "URI de redireccionamento",
    "Client Identifier" : "Identificador do cliente",
    "Secret" : "Secreto",
    "Add client" : "Engadir cliente",
    "Add" : "Engadir",
    "Show client secret" : "Amosar o secreto do cliente",
    "Delete" : "Eliminar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.8p0.tgz: nextcloud/apps/oauth2/l10n/gl.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "O seu cliente non ten autorización para conectarse. Informe do seu cliente ao administrador.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "o seu URL de redirección debe ser un URL completo, por exemplo: https://omeudominio.com/ruta",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Permite a autenticación compatíbel con OAuth2 dende outras aplicacións web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "A aplicación OAuth2 permítelle aos administradores configurar o fluxo de traballo de autenticación incorporado para permitir tamén autenticación compatíbel con OAuth2 dende outras aplicacións web.",
    "OAuth 2.0 clients" : "Clientes OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 permítelle aos servizos externos solicitar acceso a {instanceName}.",
    "Add client" : "Engadir cliente",
    "Name" : "Nome",
    "Redirection URI" : "URI de redireccionamento",
    "Add" : "Engadir",
    "Client Identifier" : "Identificador do cliente",
    "Secret" : "Segredo",
    "Show client secret" : "Amosar o segredo do cliente",
    "Delete" : "Eliminar"
},
"nplurals=2; plural=(n != 1);");
